@@ -367,11 +367,11 @@ parser.add_argument(
     - re      正则表达式模块
 """)
 parser.add_argument(
-    "-dn", "--direct-open-names", nargs="+", metavar="name", 
+    "-dn", "--direct-open-names", nargs="*", default=[], metavar="name", 
     help="为这些名字（忽略大小写）的程序直接打开链接", 
 )
 parser.add_argument(
-    "-de", "--direct-open-exes", nargs="+", metavar="exec", 
+    "-de", "--direct-open-exes", nargs="*", default=[], metavar="exec", 
     help="为这些路径的程序直接打开链接", 
 )
 parser.add_argument("-c", "--make-cache", help="""\
